@@ -2,6 +2,16 @@ from logilab.common.testlib import unittest_main
 from cubicweb import ValidationError
 from cubicweb.devtools.testlib import CubicWebTC
 
+class ContainerLessTC(CubicWebTC):
+
+    def test_free_from_container(self):
+        l = self.request().create_entity('Left')
+        self.assertEqual(None, l.cw_adapt_to('Container').related_container)
+        self.assertEqual(None, l.cw_adapt_to('Container').parent)
+        self.commit()
+        self.assertEqual(None, l.cw_adapt_to('Container').related_container)
+        self.assertEqual(None, l.cw_adapt_to('Container').parent)
+
 class ContainerEntitiesTC(CubicWebTC):
 
     def setup_database(self):
@@ -13,6 +23,11 @@ class ContainerEntitiesTC(CubicWebTC):
         self.b1 = req.create_entity('Bottom', top_by_left=self.l)
         self.b2 = req.create_entity('Bottom', top_by_right=self.r)
 
+    def test_container_relation_hook(self):
+        req = self.request()
+        u = req.create_entity('NearTop', reverse_has_near_top=self.d)
+        self.commit()
+
     def test_container_rtype_hook(self):
         self.assertEqual(len(self.execute('Any X,Y WHERE X diamond Y')), 4)
         req = self.request()
